
'''
The global settings prefix can be changed by modifying the `SETTINGS_PREFIX`
variable. These settings can be overwritten by modifying the Django settings
(in that case the `SETTINGS_PREFIX` is used) or by modifying this file.
'''
#SETTINGS_PREFIX = 'MAILJET_'

'''The Mailjet authentication data'''
#API_KEY = None
#SECRET_KEY = None

'''The timeout for the POST/GET requests'''
#TIMEOUT = 10

'''The API version, currently only 0.1 is suported'''
#VERSION = 0.1

'''The url to fetch from, this is based on the version but this is not
required'''
#URL = 'https://api.mailjet.com/%(VERSION)s/'




'''These are the default settings, DON'T MODIFY THIS FILE!

If (some) of these settings need changing, do that in `settings.py` instead


The global settings prefix can be changed by modifying the `SETTINGS_PREFIX`
variable. These settings can be overwritten by modifying the Django settings
(in that case the `SETTINGS_PREFIX` is used) or by modifying `settings.py`
'''

SETTINGS_PREFIX = 'MAILJET_'
API_KEY = ''
SECRET_KEY = ''
TIMEOUT = 10
VERSION = 0.1
URL = 'https://api.mailjet.com/%(VERSION)s/'




from mailjet import default_settings
import os
import pprint

# Try to use Django settings if these are available
try:
    from django.conf import settings as django_settings
except ImportError:
    django_settings = None

# Also try the local settings, mostly used for testing
try:
    from mailjet import settings as local_settings
except ImportError:
    local_settings = None


__all__ = ['settings']

class Setting(object):
    def __init__(self, key, name=None,
            prefix=default_settings.SETTINGS_PREFIX, processors=None):
        '''Settings object that automatically fetches the settings from the 
        django settings, local overrides or local defaults
        
        key -- the variable name to look for
        name -- optional: the variable to write to, defaults to `key`
        prefix -- when looking in the django settings, use this prefix
        processors -- post-processing for the settings
        '''
        self.name = name or key
        self.key = key
        self.prefix = prefix
        self.processors = self.get_processors(processors)
        
    @classmethod
    def get_processors(cls, processors):
        if not processors:
            # None or empty list
            processors = []
        elif isinstance(processors, list):
            # List is allowed
            pass
        elif isinstance(processors, tuple):
            # Tuples need to be converted
            processors = list(processors)
        else:
            # Convert the rest into a list
            processors = [processors]
        
        return list(processors)
    
    def _get(self, settings, key):
        prefixed_key = self.prefix + key
        if prefixed_key in os.environ:
            return os.environ[prefixed_key]
        
        elif hasattr(django_settings, prefixed_key):
            return getattr(django_settings, prefixed_key)
        
        else:
            for settings in (local_settings, default_settings):
                if hasattr(settings, key):
                    return getattr(settings, key)
            
    def __call__(self, settings):
        value = self._get(settings, self.key)
        
        for processor in self.processors:
            value = processor(settings=settings, setting=self, value=value)
        
        return value

class ExecutablePathMixin(object):
    def _get(self, settings, key):
        paths = super(ExecutablePathMixin, self)._get(settings, key)
        for path in paths:
            if os.path.isfile(path) and os.access(path, os.X_OK):
                return path

class WritablePathMixin(object):
    def _get(self, settings, key):
        paths = super(WritablePathMixin, self)._get(settings, key)
        for path in paths:
            if os.path.isfile(path) and os.access(path, os.W_OK):
                return path

class StringFormattingMixin(object):
    def _get(self, settings, key):
        value = super(StringFormattingMixin, self)._get(settings, key)
        return value % settings

class WritablePathSetting(WritablePathMixin, Setting): pass
class ExecutablePathSetting(ExecutablePathMixin, Setting): pass
class FormattedSetting(StringFormattingMixin, Setting): pass
class FormattedExecutablePathSetting(StringFormattingMixin,
    ExecutablePathSetting): pass
class FormattedWritablePathSetting(StringFormattingMixin,
    WritablePathSetting): pass

class Settings(object):
    _settings_cache = {}
    _settings = (
        FormattedSetting('API_KEY'),
        FormattedSetting('SECRET_KEY'),
        Setting('TIMEOUT'),
        Setting('VERSION'),
        FormattedSetting('URL'),
    )
    
    def __init__(self):
        if not self._settings_cache:
            for setting in self._settings:
                self._settings_cache[setting.name] = setting(self)
            self._settings = ()

    def __getattr__(self, key):
        if key in self._settings_cache:
            return self._settings_cache[key]
        else:
            value = getattr(django_settings, key)
        
        self._settings_cache[key] = value
        return value
        
    def __getitem__(self, key):
        return self.__getattr__(key)

    def __setattr__(self, key, value):
        self._settings_cache[key] = value
    
    def __repr__(self):
        return '<%s %s>' % (
            self.__class__.__name__,
            pprint.pformat(self._settings_cache),
        )

settings = Settings()




import urllib
import urllib2
from mailjet.conf import settings

class Connection(object):
    def __init__(self, access_key=None, secret_key=None, timeout=None):
        self.access_key = access_key or settings.API_KEY
        self.secret_key = secret_key or settings.SECRET_KEY
        self.timeout = timeout or settings.TIMEOUT
        self.opener = None

    def get_opener(self, url):
        if not self.opener:
            # Add the authentication data to a password manager
            password_mgr = urllib2.HTTPPasswordMgrWithDefaultRealm()
            password_mgr.add_password(
                'Mailjet API',
                settings.URL,
                self.access_key,
                self.secret_key,
            )
            # Create a handler for this password manager
            handler = urllib2.HTTPBasicAuthHandler(password_mgr)
            # Create an opener for the handler
            self.opener = urllib2.build_opener(handler)

        return self.opener

    def open(self, method, function, options=None, postdata=None):
        url = u'%s%s%s' % (settings.URL, method, function)
        default_options = {
            'output': 'json',
        }
        if options:
            default_options.update(options)

        url += '?' + urllib.urlencode(default_options)
        if postdata:
            poststring = urllib.urlencode(postdata.items())
        else:
            poststring = None

        opener = self.get_opener(url)
        return opener.open(url, poststring, self.timeout)

    @classmethod
    def get_connection(cls, access_key, secret_key):
        return Connection(access_key, secret_key)
  



from mailjet.connection import Connection
import json

class Api(object):
    def __init__(self, connection=None, access_key=None, secret_key=None):
        if not connection:
            connection = Connection.get_connection(access_key, secret_key)

        self.connection = connection

    def __getattr__(self, method):
        return ApiMethod(self, method)

class ApiMethod(object):
    def __init__(self, api, method):
        self.api = api
        self.method = method

    def __getattr__(self, function):
        return ApiMethodFunction(self, function)

    def __unicode__(self):
        return self.method

class ApiMethodFunction(object):
    def __init__(self, method, function):
        self.method = method
        self.function = function

    def __call__(self, **kwargs):
        response = self.method.api.connection.open(
            self.method,
            self.function,
            postdata=kwargs,
        )
        return json.load(response)

    def __unicode__(self):
        return self.function




import os
from setuptools import setup

if os.path.isfile('README.rst'):
    long_description = open('README.rst').read()
else:
    long_description = 'See http://pypi.python.org/pypi/mailjet/'

setup(
    name = 'mailjet',
    version = '1.0',
    author = 'Rick van Hattem',
    author_email = 'Rick.van.Hattem@Fawo.nl',
    description = '''mailjet is a django app to implement the mailjet REST
        API''',
    url='https://github.com/WoLpH/mailjet',
    license = 'BSD',
    packages=['mailjet'],
    long_description=long_description,
    test_suite='nose.collector',
    tests_require=['nose'],
    classifiers=[
        'License :: OSI Approved :: BSD License',
    ],
)

